# -*- encoding: utf-8 -*-

import os
import settings
import md5

#fixed
TEXT_IMAGE_ROOT = settings.MEDIA_ROOT
TEXT_IMAGE_URL = settings.MEDIA_URL

#overridable
TEXT_IMAGE_FOLDER = 'text_images'
TEXT_IMAGE_FONT = '/usr/share/fonts/truetype/freefont/FreeMono.ttf'
TEXT_IMAGE_SIZE = 16
TEXT_IMAGE_CSS_CLASS = 'text-image'
TEXT_IMAGE_COLOR = 'black'

# Check for settings values presence
if not hasattr(settings, 'TEXT_IMAGE_FOLDER'):
    settings.TEXT_IMAGE_FOLDER = TEXT_IMAGE_FOLDER

if not hasattr(settings, 'TEXT_IMAGE_FONT'):
    settings.TEXT_IMAGE_FONT = TEXT_IMAGE_FONT

if not hasattr(settings, 'TEXT_IMAGE_SIZE'):
    settings.TEXT_IMAGE_SIZE = TEXT_IMAGE_SIZE

if not hasattr(settings, 'TEXT_IMAGE_CSS_CLASS'):
    settings.TEXT_IMAGE_CSS_CLASS = TEXT_IMAGE_CSS_CLASS

if not hasattr(settings, 'TEXT_IMAGE_COLOR'):
    settings.TEXT_IMAGE_COLOR = TEXT_IMAGE_COLOR

# Prepare folder to receive generated images
text_images_folder = os.path.join(TEXT_IMAGE_ROOT, settings.TEXT_IMAGE_FOLDER)
if not os.path.exists(text_images_folder):
    os.mkdir(text_images_folder)

class Text2Image(object):
    """
    This class provide provide an abstract way to convert text to image, without dealing
    about storage and image manipulation.
    """
    text = None
    id_text = None

    def __init__(self, text=""):
        self.set_text(text)

    def set_text(self, text):
        """Generate secret key non reversible"""
        self.text = text
        self.id_text = md5.md5(self.text).hexdigest()

    def get_path(self):
        return os.path.join(TEXT_IMAGE_ROOT, settings.TEXT_IMAGE_FOLDER, self.id_text)

    def generate_image(self,):
        import Image, ImageDraw, ImageFont
        fontPath = settings.TEXT_IMAGE_FONT
        font = ImageFont.truetype(fontPath, settings.TEXT_IMAGE_SIZE)
        size = font.getsize(self.text)
        im = Image.new('RGBA', size, (0, 0, 0, 0))
        draw = ImageDraw.Draw(im)
        draw.text((0, 0), self.text, font=font, fill=settings.TEXT_IMAGE_COLOR)
        im.save(self.get_path(), "png")

    def get_image(self,):
        """Return image object"""
        path = self.get_path()
        if not os.path.exists(path):
            self.generate_image()
        return Image.open(path)

    def get_html_image(self, regenerate=False):
        """Render HTML tag with corresponding image"""
        if regenerate:
            self.generate_image()
        path = os.path.join(TEXT_IMAGE_URL, settings.TEXT_IMAGE_FOLDER, self.id_text)
        html = "<img class='%s' src='%s'/>" % (settings.TEXT_IMAGE_CSS_CLASS, path)
        return html
    


